import React, { createContext, useContext, useState } from 'react';
import { Container, DefaultProperties } from '@react-three/uikit';
import { ChevronDown } from '@react-three/uikit-lucide';
const AccordionContext = createContext(null);
export function Accordion({ children }) {
    const stateHandler = useState(undefined);
    return (React.createElement(Container, { flexDirection: "column" },
        React.createElement(AccordionContext.Provider, { value: stateHandler }, children)));
}
const AccordionItemContext = createContext('');
export function AccordionItem({ children, ...props }) {
    const [value, setValue] = useContext(AccordionContext);
    const isSelected = props.value === value;
    return (React.createElement(Container, { cursor: "pointer", flexDirection: "column", onClick: () => setValue(isSelected ? undefined : props.value), borderBottom: 1, ...props },
        React.createElement(AccordionItemContext.Provider, { value: props.value }, children)));
}
export function AccordionTrigger({ children, ...props }) {
    const itemValue = useContext(AccordionItemContext);
    const [value] = useContext(AccordionContext);
    const isSelected = itemValue === value;
    return (React.createElement(Container, { flexDirection: "row", flexGrow: 1, flexShrink: 1, alignItems: "center", justifyContent: "space-between", paddingY: 16, ...props },
        React.createElement(DefaultProperties, { fontWeight: "medium" }, children),
        React.createElement(ChevronDown, { transformRotateZ: isSelected ? 180 : 0, width: 16, height: 16, flexShrink: 0 })));
}
export function AccordionContent({ children, ...props }) {
    const itemValue = useContext(AccordionItemContext);
    const [value] = useContext(AccordionContext);
    if (value != itemValue) {
        return null;
    }
    return (React.createElement(Container, { overflow: "hidden", ...props },
        React.createElement(Container, { paddingBottom: 16 },
            React.createElement(DefaultProperties, { fontSize: 14 }, children))));
}
