import { Container } from '@react-three/uikit';
import React, { createContext, useContext, useMemo, useState } from 'react';
import { colors } from './theme';
const RadioGroupContext = createContext({});
export function RadioGroup({ defaultValue, value: providedValue, onValueChange, children, ...props }) {
    const [uncontrolled, setUncontrolled] = useState(defaultValue);
    const contextValue = useMemo(() => {
        if (providedValue == null) {
            return {
                value: uncontrolled,
                setValue: (value) => {
                    setUncontrolled(value);
                    onValueChange?.(value);
                },
            };
        }
        return {
            value: providedValue,
            onValueChange,
        };
    }, [uncontrolled, onValueChange, providedValue]);
    return (React.createElement(Container, { flexDirection: "column", gap: 8, ...props },
        React.createElement(RadioGroupContext.Provider, { value: contextValue }, children)));
}
export function RadioGroupItem({ disabled = false, value, children, ...props }) {
    const { value: current, setValue } = useContext(RadioGroupContext);
    return (React.createElement(Container, { cursor: disabled ? undefined : 'pointer', onClick: disabled ? undefined : () => setValue?.(value), flexDirection: "row", alignItems: "center", gap: 8 },
        React.createElement(Container, { aspectRatio: 1, height: 16, width: 16, borderRadius: 1000, border: 1, borderOpacity: disabled ? 0.5 : undefined, borderColor: colors.primary, alignItems: "center", justifyContent: "center", ...props },
            React.createElement(Container, { borderRadius: 1000, aspectRatio: 1, backgroundColor: colors.primary, backgroundOpacity: value === current ? 1 : 0, height: 9, width: 9 })),
        children));
}
