import { Container } from '@react-three/uikit';
import { colors } from './theme';
import React, { useMemo, useRef, useState } from 'react';
import { Vector3 } from 'three';
const vectorHelper = new Vector3();
export function Slider({ disabled = false, value: providedValue, defaultValue, onValueChange, min = 0, max = 100, step = 1, ...props }) {
    const [uncontrolled, setUncontrolled] = useState(defaultValue);
    const value = providedValue ?? uncontrolled ?? 50;
    const range = max - min;
    const percentage = `${(100 * value) / range}%`;
    const ref = useRef(null);
    const onChange = useRef(onValueChange);
    onChange.current = onValueChange;
    const hasProvidedValue = providedValue != null;
    const handler = useMemo(() => {
        let down = false;
        function setValue(e) {
            if (ref.current == null) {
                return;
            }
            vectorHelper.copy(e.point);
            ref.current.interactionPanel.worldToLocal(vectorHelper);
            const newValue = Math.min(Math.max(Math.round(((vectorHelper.x + 0.5) * (max - min) + min) / step) * step, min), max);
            if (!hasProvidedValue) {
                setUncontrolled(newValue);
            }
            onChange.current?.(newValue);
            e.stopPropagation();
        }
        return {
            onPointerDown(e) {
                down = true;
                setValue(e);
                e.target.setPointerCapture(e.pointerId);
            },
            onPointerMove(e) {
                if (!down) {
                    return;
                }
                setValue(e);
            },
            onPointerUp(e) {
                if (!down) {
                    return;
                }
                down = false;
                e.stopPropagation();
            },
        };
    }, [max, min, hasProvidedValue, step]);
    return (React.createElement(Container, { ref: ref, ...(disabled ? {} : handler), positionType: "relative", flexDirection: "column", height: 8, width: "100%", alignItems: "center", ...props },
        React.createElement(Container, { height: 8, positionType: "absolute", positionLeft: 0, positionRight: 0, flexGrow: 1, borderRadius: 1000, backgroundColor: colors.secondary },
            React.createElement(Container, { height: "100%", width: percentage, borderRadius: 1000, backgroundColor: colors.primary })),
        React.createElement(Container, { zIndexOffset: { minor: 100 }, positionType: "absolute", positionLeft: percentage, transformTranslateX: -10, transformTranslateY: -6, cursor: "pointer", borderOpacity: disabled ? 0.5 : undefined, backgroundOpacity: disabled ? 0.5 : undefined, height: 20, width: 20, border: 2, borderRadius: 1000, borderColor: colors.primary, backgroundColor: colors.background })));
}
