import { Container, DefaultProperties } from '@react-three/uikit';
import React, { createContext, useContext, useMemo, useState } from 'react';
import { colors } from './theme';
const TabsContext = createContext({});
export function Tabs({ value: providedValue, onValueChange, defaultValue, children, ...props }) {
    const [uncontrolled, setUncontrolled] = useState(defaultValue);
    const contextValue = useMemo(() => {
        if (providedValue == null) {
            return {
                value: uncontrolled,
                setValue: (value) => {
                    setUncontrolled(value);
                    onValueChange?.(value);
                },
            };
        }
        return {
            value: providedValue,
            setValue: onValueChange,
        };
    }, [uncontrolled, onValueChange, providedValue]);
    return (React.createElement(Container, { flexDirection: "column", ...props },
        React.createElement(TabsContext.Provider, { value: contextValue }, children)));
}
export function TabsList({ children, ...props }) {
    return (React.createElement(Container, { height: 40, flexDirection: "row", alignItems: "center", borderRadius: 6, backgroundColor: colors.muted, padding: 4, flexShrink: 0, ...props },
        React.createElement(DefaultProperties, { color: colors.mutedForeground }, children)));
}
export function TabsTrigger({ children, value, disabled = false, ...props }) {
    const { setValue, value: current } = useContext(TabsContext);
    const active = value === current;
    return (React.createElement(Container, { onClick: disabled ? undefined : (e) => setValue?.(value), cursor: disabled ? undefined : 'pointer', flexDirection: "row", alignItems: "center", borderRadius: 2, paddingX: 12, backgroundOpacity: disabled ? 0.5 : undefined, backgroundColor: active ? colors.background : undefined, paddingY: 6, justifyContent: "center", ...props },
        React.createElement(DefaultProperties, { opacity: disabled ? 0.5 : undefined, color: active ? colors.foreground : undefined, fontSize: 14, fontWeight: "medium", lineHeight: 1.43, wordBreak: "keep-all" }, children)));
}
export function TabsContent({ value, ...props }) {
    const { value: current } = useContext(TabsContext);
    if (value != current) {
        return null;
    }
    return React.createElement(Container, { marginTop: 8, ...props });
}
