import { Container, DefaultProperties } from '@react-three/uikit';
import React, { createContext, useContext, useState } from 'react';
import { colors } from './theme';
const toggleVariants = {
    default: {
        containerHoverProps: undefined,
        containerProps: undefined,
    },
    outline: {
        containerProps: {
            border: 1,
            borderColor: colors.input,
        },
        containerHoverProps: {
            backgroundColor: colors.accent,
        },
    },
    //TODO: hover:text-accent-foreground
};
const toggleSizes = {
    default: { height: 40, paddingX: 12 },
    sm: { height: 36, paddingX: 10 },
    lg: { height: 44, paddingX: 20 },
};
const ToggleGroupContext = createContext({ size: 'default', variant: 'default' });
export function ToggleGroup({ children, size = 'default', variant = 'default', ...props }) {
    return (React.createElement(Container, { flexDirection: "row", alignItems: "center", justifyContent: "center", gap: 4, ...props },
        React.createElement(ToggleGroupContext.Provider, { value: { variant, size } }, children)));
}
export function ToggleGroupItem({ children, defaultChecked, checked: providedChecked, disabled = false, onCheckedChange, hover, ...props }) {
    const { size, variant } = useContext(ToggleGroupContext);
    const [uncontrolled, setUncontrolled] = useState(defaultChecked ?? false);
    const checked = providedChecked ?? uncontrolled;
    return (React.createElement(Container, { onClick: disabled
            ? undefined
            : () => {
                if (providedChecked == null) {
                    setUncontrolled(!checked);
                }
                onCheckedChange?.(!checked);
            }, alignItems: "center", justifyContent: "center", borderRadius: 6, cursor: disabled ? undefined : 'pointer', backgroundOpacity: disabled ? 0.5 : undefined, borderOpacity: disabled ? 0.5 : undefined, backgroundColor: checked ? colors.accent : undefined, hover: disabled ? hover : { backgroundColor: colors.muted, ...toggleVariants[variant].containerHoverProps, ...hover }, ...toggleVariants[variant].containerProps, ...toggleSizes[size], ...props },
        React.createElement(DefaultProperties, { color: checked ? colors.accentForeground : undefined, opacity: disabled ? 0.5 : undefined, fontSize: 14, lineHeight: 1.43 }, children)));
    //TODO: hover:text-muted-foreground
}
