import { Container, DefaultProperties } from '@react-three/uikit';
import React, { createContext, useContext, useEffect, useRef, useState } from 'react';
import { colors } from './theme';
const TooltipContext = createContext(null);
export function Tooltip({ children, ...props }) {
    const [open, setOpen] = useState(false);
    const timeoutRef = useRef(undefined);
    useEffect(() => () => {
        if (timeoutRef.current == null) {
            return;
        }
        clearTimeout(timeoutRef.current);
    }, []);
    return (React.createElement(Container, { onPointerOver: () => {
            if (timeoutRef.current != null) {
                return;
            }
            timeoutRef.current = setTimeout(() => {
                timeoutRef.current = undefined;
                setOpen(true);
            }, 1000);
        }, onPointerOut: () => {
            if (timeoutRef.current != null) {
                clearTimeout(timeoutRef.current);
                timeoutRef.current = undefined;
                return;
            }
            setOpen(false);
        }, positionType: "relative", flexDirection: "column", alignItems: "center", ...props },
        React.createElement(TooltipContext.Provider, { value: open }, children)));
}
export function TooltipTrigger(props) {
    return React.createElement(Container, { alignSelf: "stretch", ...props });
}
export function TooltipContent({ children, sideOffset = 4, ...props }) {
    const open = useContext(TooltipContext);
    if (!open) {
        return null;
    }
    return (React.createElement(Container, { positionType: "absolute", positionBottom: "100%", marginBottom: sideOffset, zIndexOffset: 50, overflow: "hidden", borderRadius: 6, border: 1, backgroundColor: colors.popover, paddingX: 12, paddingY: 6, ...props },
        React.createElement(DefaultProperties, { wordBreak: "keep-all", fontSize: 14, lineHeight: 1.4333, color: colors.popoverForeground }, children)));
}
